==> homesitemaker-v0.4.2.tar.gz: homesitemaker/includes/control-panel/users/cp_my_acount.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


include ("includes/languages/".$LANGUAGE."/homesite-includes-control-panel-users-cp_my_account.php");

// Show the user data for the current user
echo "<tr><td class=\"title1\" colspan=\"2\">$TEXT001 ".$user_result["nick"]." $TEXT002</td></tr>".
     "<tr><td colspan=\"2\">&nbsp;</td><tr>".
     "<tr><td class=\"text2\"><b>$TEXT003</b>: ".$user_result["nick"]."</td>".
     "<td class=\"text2\"rowspan=4><b>$TEXT004</b>: <img src=".$user_result["user_photo_file"]." valign=\"top\"></td></tr>".
     "<tr><td class=\"text2\"><b>$TEXT005</b>: ".$user_result["real_name"]."</td></tr>".
     "<tr><td class=\"text2\"><b>$TEXT006</b>: ".$user_result["email"]."</td></tr>".
     "<tr><td class=\"text2\"><b>$TEXT007</b>: ".$user_result["level"]."</td></tr>";


if (isset($_GET['top_tab'])) {$top_tab=$_GET['top_tab'];} else {$top_tab="";}
if (isset($_GET['section_type'])) {$section_type=$_GET['section_type'];} else {$section_type="1";}
if (isset($_GET['task'])) {$task=$_GET['task'];} else {$task="0";}

// If the user was login has a athorized user, then the system shows the edit and delete options
if ($id_session[num]==$num && $id_session[num]!="NULL" && $task!="edit")
  {
  echo "<tr><td class=\"text6\" colspan=\"2\">&nbsp;</td></tr>".
       "<tr><td class=\"text6\" colspan=\"2\"><hr color=\"blue\" size=\"2\"></td></tr>".
       "<tr><td class=\"text2b\" colspan=\"2\" align=\"right\">".
       "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type&user_section=1&num=$num&task=edit\">$TEXT008</a>&nbsp;&nbsp;".
       "</td></tr>";
  }
// If the user was loged in and select the edit option (task=edit), then he can modify the whole section.
if ($id_session[num] == $num && $task=="edit" && $id_session[num] != "")
  {
 echo "<form enctype=\"multipart/form-data\" method=\"post\" ".
      "action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num&user_section=1\">".
      "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_edit_user\">".
      "<input type=\"hidden\" name=\"num\" value=\"$num\">".
      "<input type=\"hidden\" name=\"id_user\" value=\"".$user_result["id_user"]."\">".
      "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">".
      "<tr><td class=\"text2b\" colspan=2><br>Nick:</td></tr>".
      "<tr><td colspan=\"2\">".
      "<input type=\"text\" size=40 name=\"new_nick\" value=\"".$user_result["nick"]."\"></input></tr>".
      "<tr><td class=\"text2\" colspan=2><br><b>$TEXT005:</b>($TEXT009)</td></tr>".
      "<tr><td colspan=\"2\"><input type=\"text\" ".
      "size=40 name=\"real_name\" value=\"".$user_result["real_name"]."\"></input></tr>".
      "<tr><td class=\"text2\" colspan=2><br><b>$TEXT006:</b>($TEXT009)</td></tr>".
      "<tr><td colspan=\"2\">".
      "<input type=\"text\" size=40 name=\"email\" value=\"".$user_result["email"]."\"></input></tr>".
      "<tr><td class=\"text2\" colspan=2><br><b>$TEXT004:</b>&nbsp;($TEXT009)</td></tr>".
      "<tr><td class=\"text1\" colspan=2>".
      "<input type=\"file\" name=\"user_photo[]\" size=40 >&nbsp;&nbsp;&nbsp;</input></td></tr>";
  if ($current_user["level"] == "99")
     {
     echo "<tr><td class=\"text2b\" colspan=2><br>Level:</td></tr>".
          "<tr><td colspan=\"2\">".
          "<input type=\"select\" size=40 name=\"level\" value=\"".$user_result["level"]."\"></input></tr>";
     }
  echo "<tr><td class=\"text2b\" colspan=2><br>$TEXT010:</td></tr>".
       "<tr><td colspan=\"2\">".
       "<input type=\"password\" size=40 name=\"password\" value=\"".$user_result["password"]."\"></input></tr>".
       "<tr><td class=\"text2b\" colspan=2><br>$TEXT011:</td></tr>".
       "<tr><td colspan=\"2\">".
       "<input type=\"password\" size=40 name=\"password_check\" value=\"".$user_result["password"]."\"></input></tr>".
       "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><br>".
       "<input type=\"submit\" value=\"$TEXT012\"></input><br></td></tr>".
       "</form>";
  }

?>

==> homesitemaker-v0.4.7.tar.gz: homesitemaker/includes/control-panel/users/cp_my_acount.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


include ("includes/languages/".$LANGUAGE."/homesite-includes-control-panel-users-cp_my_account.php");

// Show the user data for the current user
echo "<tr><td class=\"title1\" colspan=\"2\">".
     "<img src=\"images/skins/$ICONS/icons/png/$ICON_SIZE2/My_Account.png\"> $TEXT001 ".$user_result["nick"]." $TEXT002</td></tr>".
     "<tr><td colspan=\"2\">&nbsp;</td><tr>".
     "<tr><td class=\"text2\"><b>$TEXT003</b>: ".$user_result["nick"]."</td>".
     "<td class=\"text2\"rowspan=4><b>$TEXT004</b>: <img src=".$user_result["user_photo_file"]." valign=\"top\" align=\"right\"></td></tr>".
     "<tr><td class=\"text2\"><b>$TEXT005</b>: ".$user_result["real_name"]."</td></tr>".
     "<tr><td class=\"text2\"><b>$TEXT006</b>: ".$user_result["email"]."</td></tr>".
     "<tr><td class=\"text2\"><b>$TEXT007</b>: ".$user_result["level"]."</td></tr>";


if (isset($_GET['top_tab'])) {$top_tab=$_GET['top_tab'];} else {$top_tab="";}
if (isset($_GET['section_type'])) {$section_type=$_GET['section_type'];} else {$section_type="1";}
if (isset($_GET['task'])) {$task=$_GET['task'];} else {$task="0";}

// If the user was login has a athorized user, then the system shows the edit and delete options
if ($id_session[num]==$num && $id_session[num]!="NULL" && $task!="edit")
  {
  echo "<tr><td class=\"text6\" colspan=\"2\">&nbsp;</td></tr>".
       "<tr><td class=\"text6\" colspan=\"2\"><hr color=$BLC size=$BLS></td></tr>".
       "<tr><td class=\"text2b\" colspan=\"2\" align=\"right\">".
       "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type&user_section=1&num=$num&task=edit\">$TEXT008</a>&nbsp;&nbsp;".
       "</td></tr>";
  }
// If the user was loged in and select the edit option (task=edit), then he can modify the whole section.
if ($id_session[num] == $num && $task=="edit" && $id_session[num] != "")
  {
 echo "<form enctype=\"multipart/form-data\" method=\"post\" ".
      "action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num&user_section=1\">".
      "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_edit_user\">".
      "<input type=\"hidden\" name=\"num\" value=\"$num\">".
      "<input type=\"hidden\" name=\"id_user\" value=\"".$user_result["id_user"]."\">".
      "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">".
      "<tr><td class=\"text2b\" colspan=2><br>Nick:</td></tr>".
      "<tr><td colspan=\"2\">".
      "<input type=\"text\" size=40 name=\"new_nick\" value=\"".$user_result["nick"]."\"></input></tr>".
      "<tr><td class=\"text2\" colspan=2><br><b>$TEXT005:</b>($TEXT009)</td></tr>".
      "<tr><td colspan=\"2\"><input type=\"text\" ".
      "size=40 name=\"real_name\" value=\"".$user_result["real_name"]."\"></input></tr>".
      "<tr><td class=\"text2\" colspan=2><br><b>$TEXT006:</b>($TEXT009)</td></tr>".
      "<tr><td colspan=\"2\">".
      "<input type=\"text\" size=40 name=\"email\" value=\"".$user_result["email"]."\"></input></tr>".
      "<tr><td class=\"text2\" colspan=2><br><b>$TEXT004:</b>&nbsp;($TEXT009)</td></tr>".
      "<tr><td class=\"text1\" colspan=2>".
      "<input type=\"file\" name=\"user_photo[]\" size=40 >&nbsp;&nbsp;&nbsp;</input></td></tr>";
  if ($current_user["level"] == "99")
     {
     echo "<tr><td class=\"text2b\" colspan=2><br>Level:</td></tr>".
          "<tr><td colspan=\"2\">".
          "<input type=\"select\" size=40 name=\"level\" value=\"".$user_result["level"]."\"></input></tr>";
     }
  echo "<tr><td class=\"text2b\" colspan=2><br>$TEXT010:</td></tr>".
       "<tr><td colspan=\"2\">".
       "<input type=\"password\" size=40 name=\"password\" value=\"".$user_result["password"]."\"></input></tr>".
       "<tr><td class=\"text2b\" colspan=2><br>$TEXT011:</td></tr>".
       "<tr><td colspan=\"2\">".
       "<input type=\"password\" size=40 name=\"password_check\" value=\"".$user_result["password"]."\"></input></tr>".
       "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><br>".
       "<input type=\"submit\" value=\"$TEXT012\"></input><br></td></tr>".
       "</form>";
  }

?>
